@@ -1,20 +1,31 @@
 package App::GitGot;
-use Moose;
-extends 'MooseX::App::Cmd';
+$App::GitGot::VERSION = '1.23'; # TRIAL
 # ABSTRACT: A tool to make it easier to manage multiple git repositories.
-use version; our $VERSION = qv("v0.01");
+use 5.014;
+use feature 'unicode_strings';
+
+use App::Cmd::Setup -app;
+
+
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::GitGot - A tool to make it easier to manage multiple git repositories.
 
 =head1 VERSION
 
-version 0.1
+version 1.23
+
+=head1 SYNOPSIS
+
+See C<perldoc got> for usage information.
 
 =head1 AUTHOR
 
@@ -22,10 +33,9 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by John SJ Anderson.
+This software is copyright (c) 2014 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
