@@ -1,27 +1,34 @@
 package App::GitGot::Command::remove;
+$App::GitGot::Command::remove::VERSION = '1.23'; # TRIAL
 # ABSTRACT: remove a managed repository from your config
+use 5.014;
+use feature 'unicode_strings';
 
-use Moose;
+use List::AllUtils qw/ any /;
+
+use App::GitGot -command;
+
+use Moo;
 extends 'App::GitGot::Command';
-use 5.010;
-
-use List::MoreUtils qw/ any /;
-
-has 'force' => (
-  is          => 'rw',
-  isa         => 'Bool',
-  cmd_aliases => 'f',
-  traits      => [qw/ Getopt /],
-);
+use namespace::autoclean;
 
 sub command_names { qw/ remove rm / }
 
+sub options {
+  my( $class , $app ) = @_;
+  return (
+    [ 'force' => 'FIXME' ] ,
+  );
+}
+
+sub _use_io_page { 0 }
+
 sub _execute {
   my( $self, $opt, $args ) = @_;
 
   unless ( $self->active_repos and @$args or $self->tags) {
-    say "You need to select one or more repos to remove";
-    exit;
+    say STDERR "ERROR: You need to select one or more repos to remove";
+    exit(1);
   }
 
   my @new_repo_list;
@@ -30,9 +37,9 @@ sub _execute {
     my $number = $repo->number;
 
     if ( any { $number == $_->number } $self->active_repos ) {
-      my $name = $repo->name;
+      my $name = $repo->label;
 
-      if ( $self->force or $self->prompt_yn( "got rm: remove '$name'?" )) {
+      if ( $self->opt->force or $self->prompt_yn( "got rm: remove '$name'?" )) {
         say "Removed repo '$name'" if $self->verbose;
         next REPO;
       }
@@ -40,22 +47,27 @@ sub _execute {
     push @new_repo_list , $repo;
   }
 
-  $self->full_repo_list( \@new_repo_list );
+  $self->set_full_repo_list( \@new_repo_list );
   $self->write_config();
 }
 
 1;
 
+## FIXME docs
+
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::GitGot::Command::remove - remove a managed repository from your config
 
 =head1 VERSION
 
-version 0.1
+version 1.23
 
 =head1 AUTHOR
 
@@ -63,10 +75,9 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by John SJ Anderson.
+This software is copyright (c) 2014 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
