@@ -1,28 +1,32 @@
 package App::GitGot::Command::version;
+$App::GitGot::Command::version::VERSION = '1.23'; # TRIAL
 # ABSTRACT: display application version
+use 5.014;
+use feature 'unicode_strings';
 
-use Moose;
+use Moo;
 extends 'App::GitGot::Command';
-use 5.010;
+use namespace::autoclean;
 
-sub _execute {
-  my( $self, $opt, $args ) = @_;
-
-  say $App::GitGot::VERSION
-}
+sub _execute { say $App::GitGot::VERSION }
 
 1;
 
+## FIXME docs
+
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::GitGot::Command::version - display application version
 
 =head1 VERSION
 
-version 0.1
+version 1.23
 
 =head1 AUTHOR
 
@@ -30,10 +34,9 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by John SJ Anderson.
+This software is copyright (c) 2014 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
